#########################
Notification Email Module
#########################

The *Notification Email Module* allows you to define email templates that will
be sent to a list of recipients when a trigger is fired on a record event.

.. toctree::
   :maxdepth: 2

   configuration
   design
   releases
